@@ -4,6 +4,6 @@ rm release/other/pt2-clone &> /dev/null
 
 echo Compiling, please wait...
 gcc -DNDEBUG src/gfx/*.c src/modloaders/*.c src/smploaders/*.c src/*.c -lSDL2 -lm -Wshadow -Winit-self -Wall -Wno-missing-field-initializers -Wno-unused-result -Wno-strict-aliasing -Wextra -Wunused -Wunreachable-code -Wno-stringop-overflow -march=native -mtune=native -O3 -o release/other/pt2-clone
-rm src/gfx/*.o src/*.o &> /dev/null
+rm src/gfx/*.o src/modloaders/*.o src/smploaders/*.o src/*.o &> /dev/null
 
 echo Done. The executable can be found in \'release/other\' if everything went well.
