@@ -68,6 +68,7 @@ void loadConfig(void)
 	config.mod2WavOutputFreq = 44100;
 	config.keepEditModeAfterStepPlay = false;
 	config.maxSampleLength = 65534;
+	config.restrictedPattEditClick = false;
 
 #ifndef _WIN32
 	getcwd(oldCwd, PATH_MAX);
@@ -81,11 +82,19 @@ void loadConfig(void)
 	if (f != NULL)
 		proTrackerDotIniFound = true;
 #else
-	// check in program directory
+	// check in program executable directory (first priority)
 	f = fopen("protracker.ini", "r");
 	if (f != NULL)
 		proTrackerDotIniFound = true;
 
+	// check in ~/.config/protracker/
+	if (!proTrackerDotIniFound && changePathToHome() && chdir(".config/protracker") == 0)
+	{
+		f = fopen("protracker.ini", "r");
+		if (f != NULL)
+			proTrackerDotIniFound = true;
+	}
+
 	// check in ~/.protracker/
 	if (!proTrackerDotIniFound && changePathToHome() && chdir(".protracker") == 0)
 	{
@@ -110,11 +119,19 @@ void loadConfig(void)
 	if (f != NULL)
 		ptDotConfigFound = true;
 #else
-	// check in program directory
+	// check in program executable directory (first priority)
 	f = openPTDotConfig();
 	if (f != NULL)
 		ptDotConfigFound = true;
 
+	// check in ~/.config/protracker/
+	if (!ptDotConfigFound && changePathToHome() && chdir(".config/protracker") == 0)
+	{
+		f = openPTDotConfig();
+		if (f != NULL)
+			ptDotConfigFound = true;
+	}
+
 	// check in ~/.protracker/
 	if (!ptDotConfigFound && changePathToHome() && chdir(".protracker") == 0)
 	{
@@ -136,19 +153,21 @@ void loadConfig(void)
 #ifdef _WIN32
 	loadColorsDotIni();
 #else
-	// check in program directory
+	// check in program executable directory (first priority)
 	colorsDotIniFound = loadColorsDotIni();
 
+	// check in ~/.config/protracker/
+	if (!colorsDotIniFound && changePathToHome() && chdir(".config/protracker") == 0)
+		colorsDotIniFound = loadColorsDotIni();
+
 	// check in ~/.protracker/
 	if (!colorsDotIniFound && changePathToHome() && chdir(".protracker") == 0)
 		loadColorsDotIni();
-#endif
 
-#ifndef _WIN32
 	chdir(oldCwd);
 #endif
 
-	// use palette for generating sample data mark (invert) table
+	// make 'sample data mark' palette-invert table now
 	createSampleMarkTable();
 }
 
@@ -192,6 +211,15 @@ static bool loadProTrackerDotIni(FILE *f)
 			continue;
 		}
 
+		// RESTRICTED_PATT_EDIT_CLICK
+		else if (!_strnicmp(configLine, "RESTRICTED_PATT_EDIT_CLICK=", 27))
+		{
+			if (!_strnicmp(&configLine[27], "TRUE", 4))
+				config.restrictedPattEditClick = true;
+			else if (!_strnicmp(&configLine[27], "FALSE", 5))
+				config.restrictedPattEditClick = false;
+		}
+
 		// STEPPLAY_KEEP_EDITMODE
 		else if (!_strnicmp(configLine, "STEPPLAY_KEEP_EDITMODE=", 23))
 		{
