@@ -13,7 +13,7 @@ void downsample2xFloat(float *buffer, uint32_t originalLength);
 void downsample2xDouble(double *buffer, uint32_t originalLength);
 
 // Warning: These are slow and use normalization to prevent clipping from undershoot/overshoot!
-void downsample2x8Bit(int8_t *buffer, uint32_t originalLength);
-void downsample2x8BitU(uint8_t *buffer, uint32_t originalLength);
-void downsample2x16Bit(int16_t *buffer, uint32_t originalLength);
-void downsample2x32Bit(int32_t *buffer, uint32_t originalLength);
+bool downsample2x8Bit(int8_t *buffer, uint32_t originalLength);
+bool downsample2x8BitU(uint8_t *buffer, uint32_t originalLength);
+bool downsample2x16Bit(int16_t *buffer, uint32_t originalLength);
+bool downsample2x32Bit(int32_t *buffer, uint32_t originalLength);
