@@ -194,7 +194,7 @@ bool saveSample(bool checkIfFileExist, bool giveNewFreeFilename)
 				fputc((uint8_t)(sampleData[i] + 128), f);
 
 			if (sampleLength & 1)
-				fputc(0, f); // pad align byte
+				fputc(0, f); // pad byte needed for 8-bit samples
 
 			if (loopStart+loopLength > 2) // loop enabled?
 				fwrite(&samplerChunk, sizeof (samplerChunk), 1, f);
@@ -214,12 +214,12 @@ bool saveSample(bool checkIfFileExist, bool giveNewFreeFilename)
 
 			if (loopStart+loopLength > 2) // loop enabled?
 			{
-				iffWriteUint32(f, loopStart); // oneShotHiSamples
+				iffWriteUint32(f, loopStart); // oneShotHiSamples (loop start when loop is enabled)
 				iffWriteUint32(f, loopLength); // repeatHiSamples
 			}
 			else
 			{
-				iffWriteUint32(f, 0); // oneShotHiSamples
+				iffWriteUint32(f, sampleLength); // oneShotHiSamples (length of sample when no loop)
 				iffWriteUint32(f, 0); // repeatHiSamples
 			}
 
